RigolDSA - Heros Devices 0.8.0 documentation

Skip to content
Back to top
View this page

# RigolDSA

From: Rigol Technologies

Class: `herosdevices.hardware.rigol.RigolDSA`

Driver Quality Index: beta

A class to interface Rigol digital spectrum analyzers.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.rigol.RigolDSA` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
address | <class ‘str’> |  | Address or IP of the instrument.
default_config | str | None | None |
keep_device_open | <class ‘bool’> | True | Keep the device open after it is first opened
payload_metadata | dict | None | None |

The following JSON strings can be used to start a HERO device representation of `RigolDSA` using BOSS.

    {
        "_id": "rigol_dsa815",
        "classname": "herosdevices.hardware.rigol.RigolDSA",
        "arguments": {
            "address": "dns_name_or_ip.of.your.device"
        },
        "datasource": {
            "async": false,
            "interval": 5
        }
    }

from examples/rigol/dsa.json

    {
        "_id": "my_RigolDSA",
        "classname": "herosdevices.hardware.rigol.RigolDSA",
        "arguments": {
            "address": "<class 'str'>",
            "default_config": null,
            "keep_device_open": true,
            "payload_metadata": null
        }
    }

generated from signature